@@ -1,7 +1,7 @@
 #include "audio_decoder.h"
 
 // globals
-static AVCodec *decoder_codec = NULL;
+static const AVCodec *decoder_codec = NULL;
 static bool_t initialized = FALSE;
 
 void
@@ -166,19 +166,25 @@ audio_decoder_decode_frame(
 	AVFrame** result)
 {
 	input_frame_t* frame = state->cur_frame;
-	AVPacket input_packet;
+	AVPacket* input_packet;
 	u_char original_pad[VOD_BUFFER_PADDING_SIZE];
 	u_char* frame_end;
 	int avrc;
 
+	input_packet = av_packet_alloc();
+	if (input_packet == NULL) {
+		vod_log_error(VOD_LOG_ERR, state->request_context->log, 0,
+			"audio_decoder_decode_frame: av_packet_alloc failed");
+		return VOD_ALLOC_FAILED;
+	}
+
 	// send a frame
-	vod_memzero(&input_packet, sizeof(input_packet));
-	input_packet.data = buffer;
-	input_packet.size = frame->size;
-	input_packet.dts = state->dts;
-	input_packet.pts = state->dts + frame->pts_delay;
-	input_packet.duration = frame->duration;
-	input_packet.flags = AV_PKT_FLAG_KEY;
+	input_packet->data = buffer;
+	input_packet->size = frame->size;
+	input_packet->dts = state->dts;
+	input_packet->pts = state->dts + frame->pts_delay;
+	input_packet->duration = frame->duration;
+	input_packet->flags = AV_PKT_FLAG_KEY;
 	state->dts += frame->duration;
 
 	av_frame_unref(state->decoded_frame);
@@ -187,7 +193,8 @@ audio_decoder_decode_frame(
 	vod_memcpy(original_pad, frame_end, sizeof(original_pad));
 	vod_memzero(frame_end, sizeof(original_pad));
 
-	avrc = avcodec_send_packet(state->decoder, &input_packet);
+	avrc = avcodec_send_packet(state->decoder, input_packet);
+	av_packet_free(&input_packet);
 	if (avrc < 0)
 	{
 		vod_log_error(VOD_LOG_ERR, state->request_context->log, 0,
