@@ -29,7 +29,7 @@ typedef struct {
 ////// request params formatting functions
 
 static u_char*
-manifest_utils_write_bitmask(u_char* p, uint32_t bitmask, u_char letter)
+manifest_utils_write_bitmask32(u_char* p, uint32_t bitmask, u_char letter)
 {
 	uint32_t i;
 
@@ -48,12 +48,44 @@ manifest_utils_write_bitmask(u_char* p, uint32_t bitmask, u_char letter)
 	return p;
 }
 
-static uint32_t*
+static u_char*
+manifest_utils_write_bitmask(u_char* p, uint64_t* bitmask, uint64_t* mask_temp, uint32_t max_bits, u_char letter)
+{
+	int32_t i;
+
+	vod_memcpy(mask_temp, bitmask, sizeof(bitmask[0]) * vod_array_length_for_bits(max_bits));
+
+	for (;;)
+	{
+		i = vod_get_lowest_bit_set(mask_temp, max_bits);
+		if (i < 0)
+		{
+			break;
+		}
+
+		*p++ = '-';
+		*p++ = letter;
+		p = vod_sprintf(p, "%uD", i + 1);
+
+		vod_reset_bit(mask_temp, i);
+	}
+
+	return p;
+}
+
+static u_char*
+manifest_utils_write_track_mask(u_char* p, track_mask_t bitmask, u_char letter)
+{
+	track_mask_t mask_temp;
+	return manifest_utils_write_bitmask(p, bitmask, mask_temp, MAX_TRACK_COUNT, letter);
+}
+
+static track_mask_t*
 manifest_utils_get_tracks_mask(
 	uint32_t index,
 	sequence_tracks_mask_t* sequence_tracks_mask,
 	sequence_tracks_mask_t* sequence_tracks_mask_end,
-	uint32_t* default_tracks_mask)
+	track_mask_t* default_tracks_mask)
 {
 	sequence_tracks_mask_t* sequence_tracks_mask_cur;
 
@@ -72,15 +104,15 @@ manifest_utils_get_tracks_mask(
 
 static vod_status_t
 manifest_utils_build_request_params_string_per_sequence_tracks(
-	request_context_t* request_context, 
+	request_context_t* request_context,
 	uint32_t segment_index,
 	uint32_t sequences_mask,
 	sequence_tracks_mask_t* sequence_tracks_mask,
 	sequence_tracks_mask_t* sequence_tracks_mask_end,
-	uint32_t* default_tracks_mask,
+	track_mask_t* default_tracks_mask,
 	vod_str_t* result)
 {
-	uint32_t* tracks_mask;
+	track_mask_t* tracks_mask;
 	uint32_t i;
 	size_t result_size;
 	u_char* p;
@@ -111,23 +143,23 @@ manifest_utils_build_request_params_string_per_sequence_tracks(
 		result_size += sizeof("-f32") - 1;
 
 		// video tracks
-		if (tracks_mask[MEDIA_TYPE_VIDEO] == 0xffffffff)
+		if (vod_track_mask_are_all_bits_set(tracks_mask[MEDIA_TYPE_VIDEO]))
 		{
 			result_size += sizeof("-v0") - 1;
 		}
 		else
 		{
-			result_size += vod_get_number_of_set_bits(tracks_mask[MEDIA_TYPE_VIDEO]) * (sizeof("-v32") - 1);
+			result_size += vod_track_mask_get_number_of_set_bits(tracks_mask[MEDIA_TYPE_VIDEO]) * (sizeof("-v") - 1 + MAX_TRACK_INDEX_LEN);
 		}
 
 		// audio tracks
-		if (tracks_mask[MEDIA_TYPE_AUDIO] == 0xffffffff)
+		if (vod_track_mask_are_all_bits_set(tracks_mask[MEDIA_TYPE_AUDIO]))
 		{
 			result_size += sizeof("-a0") - 1;
 		}
 		else
 		{
-			result_size += vod_get_number_of_set_bits(tracks_mask[MEDIA_TYPE_AUDIO]) * (sizeof("-a32") - 1);
+			result_size += vod_track_mask_get_number_of_set_bits(tracks_mask[MEDIA_TYPE_AUDIO]) * (sizeof("-a") - 1 + MAX_TRACK_INDEX_LEN);
 		}
 	}
 
@@ -164,33 +196,23 @@ manifest_utils_build_request_params_string_per_sequence_tracks(
 		p = vod_sprintf(p, "-f%uD", i + 1);
 
 		// video tracks
-		switch (tracks_mask[MEDIA_TYPE_VIDEO])
+		if (vod_track_mask_are_all_bits_set(tracks_mask[MEDIA_TYPE_VIDEO]))
 		{
-		case 0xffffffff:
 			p = vod_copy(p, "-v0", sizeof("-v0") - 1);
-			break;
-
-		case 0:
-			break;
-
-		default:
-			p = manifest_utils_write_bitmask(p, tracks_mask[MEDIA_TYPE_VIDEO], 'v');
-			break;
+		}
+		else if (vod_track_mask_is_any_bit_set(tracks_mask[MEDIA_TYPE_VIDEO]))
+		{
+			p = manifest_utils_write_track_mask(p, tracks_mask[MEDIA_TYPE_VIDEO], 'v');
 		}
 
 		// audio tracks
-		switch (tracks_mask[MEDIA_TYPE_AUDIO])
+		if (vod_track_mask_are_all_bits_set(tracks_mask[MEDIA_TYPE_AUDIO]))
 		{
-		case 0xffffffff:
 			p = vod_copy(p, "-a0", sizeof("-a0") - 1);
-			break;
-
-		case 0:
-			break;
-
-		default:
-			p = manifest_utils_write_bitmask(p, tracks_mask[MEDIA_TYPE_AUDIO], 'a');
-			break;
+		}
+		else if (vod_track_mask_is_any_bit_set(tracks_mask[MEDIA_TYPE_AUDIO]))
+		{
+			p = manifest_utils_write_track_mask(p, tracks_mask[MEDIA_TYPE_AUDIO], 'a');
 		}
 	}
 
@@ -209,13 +231,13 @@ manifest_utils_build_request_params_string_per_sequence_tracks(
 
 vod_status_t
 manifest_utils_build_request_params_string(
-	request_context_t* request_context, 
-	uint32_t* has_tracks,
+	request_context_t* request_context,
+	track_mask_t* has_tracks,
 	uint32_t segment_index,
 	uint32_t sequences_mask,
 	sequence_tracks_mask_t* sequence_tracks_mask,
 	sequence_tracks_mask_t* sequence_tracks_mask_end,
-	uint32_t* tracks_mask,
+	track_mask_t* tracks_mask,
 	vod_str_t* result)
 {
 	u_char* p;
@@ -244,29 +266,29 @@ manifest_utils_build_request_params_string(
 	// sequence mask
 	if (sequences_mask != 0xffffffff)
 	{
-		result_size += vod_get_number_of_set_bits(sequences_mask) * (sizeof("-f32") - 1);
+		result_size += vod_get_number_of_set_bits32(sequences_mask) * (sizeof("-f32") - 1);
 	}
 
 	// video tracks
-	if (tracks_mask[MEDIA_TYPE_VIDEO] == 0xffffffff)
+	if (vod_track_mask_are_all_bits_set(tracks_mask[MEDIA_TYPE_VIDEO]))
 	{
 		result_size += sizeof("-v0") - 1;
 	}
 	else
 	{
-		result_size += vod_get_number_of_set_bits(tracks_mask[MEDIA_TYPE_VIDEO]) * (sizeof("-v32") - 1);
+		result_size += vod_track_mask_get_number_of_set_bits(tracks_mask[MEDIA_TYPE_VIDEO]) * (sizeof("-v") - 1 + MAX_TRACK_INDEX_LEN);
 	}
-	
+
 	// audio tracks
-	if (tracks_mask[MEDIA_TYPE_AUDIO] == 0xffffffff)
+	if (vod_track_mask_are_all_bits_set(tracks_mask[MEDIA_TYPE_AUDIO]))
 	{
 		result_size += sizeof("-a0") - 1;
 	}
 	else
 	{
-		result_size += vod_get_number_of_set_bits(tracks_mask[MEDIA_TYPE_AUDIO]) * (sizeof("-a32") - 1);
+		result_size += vod_track_mask_get_number_of_set_bits(tracks_mask[MEDIA_TYPE_AUDIO]) * (sizeof("-v") - 1 + MAX_TRACK_INDEX_LEN);
 	}
-	
+
 	p = vod_alloc(request_context->pool, result_size + 1);
 	if (p == NULL)
 	{
@@ -285,32 +307,32 @@ manifest_utils_build_request_params_string(
 	// sequence mask
 	if (sequences_mask != 0xffffffff)
 	{
-		p = manifest_utils_write_bitmask(p, sequences_mask, 'f');
+		p = manifest_utils_write_bitmask32(p, sequences_mask, 'f');
 	}
 
 	// video tracks
-	if (has_tracks[MEDIA_TYPE_VIDEO])
+	if (vod_track_mask_is_any_bit_set(has_tracks[MEDIA_TYPE_VIDEO]))
 	{
-		if (tracks_mask[MEDIA_TYPE_VIDEO] == 0xffffffff)
+		if (vod_track_mask_are_all_bits_set(tracks_mask[MEDIA_TYPE_VIDEO]))
 		{
 			p = vod_copy(p, "-v0", sizeof("-v0") - 1);
 		}
 		else
 		{
-			p = manifest_utils_write_bitmask(p, tracks_mask[MEDIA_TYPE_VIDEO], 'v');
+			p = manifest_utils_write_track_mask(p, tracks_mask[MEDIA_TYPE_VIDEO], 'v');
 		}
 	}
 	
 	// audio tracks
-	if (has_tracks[MEDIA_TYPE_AUDIO])
+	if (vod_track_mask_is_any_bit_set(has_tracks[MEDIA_TYPE_AUDIO]))
 	{
-		if (tracks_mask[MEDIA_TYPE_AUDIO] == 0xffffffff)
+		if (vod_track_mask_are_all_bits_set(tracks_mask[MEDIA_TYPE_AUDIO]))
 		{
 			p = vod_copy(p, "-a0", sizeof("-a0") - 1);
 		}
 		else
 		{
-			p = manifest_utils_write_bitmask(p, tracks_mask[MEDIA_TYPE_AUDIO], 'a');
+			p = manifest_utils_write_track_mask(p, tracks_mask[MEDIA_TYPE_AUDIO], 'a');
 		}
 	}
 
