@@ -197,6 +197,7 @@ static vod_uint_t type_key_hash = vod_hash(vod_hash(vod_hash('t', 'y'), 'p'), 'e
 
 static vod_str_t playlist_type_vod = vod_string("vod");
 static vod_str_t playlist_type_live = vod_string("live");
+static vod_str_t playlist_type_event = vod_string("event");
 
 static parser_init_t parser_init_funcs[] = {
 	gain_filter_parser_init,
@@ -432,7 +433,7 @@ media_set_parse_tracks_spec(
 	void* dest)
 {
 	media_filter_parse_context_t* context = ctx;
-	uint32_t* tracks_mask = dest;
+	track_mask_t* tracks_mask = dest;
 	u_char* end_pos = value->v.str.data + value->v.str.len;
 
 	vod_memzero(tracks_mask, sizeof(tracks_mask[0]) * MEDIA_TYPE_COUNT);
@@ -647,10 +648,10 @@ media_set_parse_source(
 	context->base.sources_head = source;
 
 	vod_log_debug4(VOD_LOG_DEBUG_LEVEL, context->base.request_context->log, 0,
-		"media_set_parse_source: parsed clip source - path=%V tracks[v]=0x%uxD tracks[a]=0x%uxD, clipFrom=%uL", 
+		"media_set_parse_source: parsed clip source - path=%V tracks[v]=0x%uxL tracks[a]=0x%uxL, clipFrom=%uL",
 		&source->mapped_uri, 
-		source->tracks_mask[MEDIA_TYPE_VIDEO],
-		source->tracks_mask[MEDIA_TYPE_AUDIO],
+		source->tracks_mask[MEDIA_TYPE_VIDEO][0],
+		source->tracks_mask[MEDIA_TYPE_AUDIO][0],
 		source->clip_from);
 
 	*result = &source->base;
@@ -904,7 +905,7 @@ media_set_parse_sequences(
 
 	if (request_params->sequence_ids[0].len == 0)
 	{
-		required_sequences_num = vod_get_number_of_set_bits(request_params->sequences_mask);
+		required_sequences_num = vod_get_number_of_set_bits32(request_params->sequences_mask);
 		required_sequences_num = vod_min(array->count, required_sequences_num);
 	}
 	else
@@ -2485,9 +2486,21 @@ media_set_parse_json(
 	{
 		result->presentation_end = TRUE;
 	}
-	else if (params[MEDIA_SET_PARAM_PLAYLIST_TYPE]->v.str.len == playlist_type_live.len &&
-		vod_strncasecmp(params[MEDIA_SET_PARAM_PLAYLIST_TYPE]->v.str.data, playlist_type_live.data, playlist_type_live.len) == 0)
+	else
 	{
+		if (params[MEDIA_SET_PARAM_PLAYLIST_TYPE]->v.str.len == playlist_type_event.len &&
+			vod_strncasecmp(params[MEDIA_SET_PARAM_PLAYLIST_TYPE]->v.str.data, playlist_type_event.data, playlist_type_event.len) == 0)
+		{
+			result->is_live_event = TRUE;
+		}
+		else if (params[MEDIA_SET_PARAM_PLAYLIST_TYPE]->v.str.len != playlist_type_live.len ||
+			vod_strncasecmp(params[MEDIA_SET_PARAM_PLAYLIST_TYPE]->v.str.data, playlist_type_live.data, playlist_type_live.len) != 0)
+		{
+			vod_log_error(VOD_LOG_ERR, request_context->log, 0,
+				"media_set_parse_json: invalid playlist type \"%V\", must be either live, vod or event", 
+				&params[MEDIA_SET_PARAM_PLAYLIST_TYPE]->v.str);
+			return VOD_BAD_MAPPING;
+		}
 		result->original_type = MEDIA_SET_LIVE;
 		if ((request_flags & REQUEST_FLAG_FORCE_PLAYLIST_TYPE_VOD) != 0)
 		{
@@ -2498,13 +2511,6 @@ media_set_parse_json(
 			result->type = MEDIA_SET_LIVE;
 		}
 	}
-	else
-	{
-		vod_log_error(VOD_LOG_ERR, request_context->log, 0,
-			"media_set_parse_json: invalid playlist type \"%V\", must be either live or vod", 
-			&params[MEDIA_SET_PARAM_PLAYLIST_TYPE]->v.str);
-		return VOD_BAD_MAPPING;
-	}
 
 	// discontinuity
 	if (params[MEDIA_SET_PARAM_DISCONTINUITY] != NULL)
@@ -2867,14 +2873,18 @@ media_set_parse_json(
 
 			if (result->type == MEDIA_SET_LIVE)
 			{
-				// trim the playlist to a smaller window if needed
-				result->live_window_duration = segmenter->live_window_duration;
-
-				if (params[MEDIA_SET_PARAM_LIVE_WINDOW_DURATION] != NULL)
+				// trim the playlist to a smaller window if needed.
+				// applying live window with infinite duration is necessary for playlistType event
+				// because we aren't allowed to remove segments from the head for this playlist type.
+				if (!result->is_live_event) 
 				{
-					result->live_window_duration = media_set_apply_live_window_duration_param(
-						result->live_window_duration,
-						params[MEDIA_SET_PARAM_LIVE_WINDOW_DURATION]->v.num.num);
+					result->live_window_duration = segmenter->live_window_duration;
+					if (params[MEDIA_SET_PARAM_LIVE_WINDOW_DURATION] != NULL)
+					{
+						result->live_window_duration = media_set_apply_live_window_duration_param(
+							result->live_window_duration,
+							params[MEDIA_SET_PARAM_LIVE_WINDOW_DURATION]->v.num.num);
+					}
 				}
 
 				if ((request_flags & REQUEST_FLAG_LOOK_AHEAD_SEGMENTS) != 0)
