@@ -76,6 +76,7 @@ typedef struct {
 	atom_info_t dinf;
 	atom_info_t elst;
 	atom_info_t tkhd;
+	atom_info_t udta_name;
 } trak_atom_infos_t;
 
 typedef struct {
@@ -191,11 +192,17 @@ static const relevant_atom_t relevant_atoms_edts[] = {
 	{ ATOM_NAME_NULL, 0, NULL }
 };
 
+static const relevant_atom_t relevant_atoms_udta[] = {
+	{ ATOM_NAME_NAME, offsetof(trak_atom_infos_t, udta_name), NULL },
+	{ ATOM_NAME_NULL, 0, NULL }
+};
+
 static const relevant_atom_t relevant_atoms_trak[] = {
 	{ ATOM_NAME_MDIA, 0, relevant_atoms_mdia },
 	{ ATOM_NAME_EDTS, 0, relevant_atoms_edts },
 	{ ATOM_NAME_TKHD, offsetof(trak_atom_infos_t, tkhd), NULL },
 	{ ATOM_NAME_SENC, offsetof(trak_atom_infos_t, senc), NULL },
+	{ ATOM_NAME_UDTA, 0, relevant_atoms_udta },
 	{ ATOM_NAME_NULL, 0, NULL }
 };
 
@@ -272,8 +279,8 @@ mp4_parser_parse_hdlr_atom(atom_info_t* atom_info, metadata_parse_context_t* con
 		break;
 	}
 	
-	// parse the name
-	if ((context->parse_params.parse_type & PARSE_FLAG_HDLR_NAME) == 0)
+	// parse the name / already set
+	if ((context->parse_params.parse_type & PARSE_FLAG_HDLR_NAME) == 0 || context->media_info.label.data != NULL)
 	{
 		return VOD_OK;
 	}
@@ -533,6 +540,36 @@ mp4_parser_parse_mdhd_atom(atom_info_t* atom_info, metadata_parse_context_t* con
 	return VOD_OK;
 }
 
+static vod_status_t
+mp4_parser_parse_udta_name_atom(atom_info_t* atom_info, metadata_parse_context_t* context)
+{
+	vod_str_t name;
+	name.data = (u_char*)atom_info->ptr;
+	name.len = atom_info->size;
+
+	// atom empty/non-existent or name already set
+	if (name.len == 0 || context->media_info.label.data != NULL)
+	{
+		return VOD_OK;
+	}
+
+	context->media_info.label.data = vod_alloc(
+		context->request_context->pool,
+		name.len + 1);
+	if (context->media_info.label.data == NULL)
+	{
+		vod_log_debug0(VOD_LOG_DEBUG_LEVEL, context->request_context->log, 0,
+			"mp4_parser_parse_udta_name_atom: vod_alloc failed");
+		return VOD_ALLOC_FAILED;
+	}
+
+	vod_memcpy(context->media_info.label.data, name.data, name.len);
+	context->media_info.label.data[name.len] = '\0';
+	context->media_info.label.len = name.len;
+
+	return VOD_OK;
+}
+
 static vod_status_t
 mp4_parser_parse_stts_atom_total_duration_only(atom_info_t* atom_info, metadata_parse_context_t* context)
 {
@@ -2191,7 +2228,7 @@ mp4_parser_parse_audio_atoms(void* ctx, atom_info_t* atom_info)
 
 		channel_layout = mp4_parser_get_ac3_channel_layout(acmod, lfeon, 0);
 
-		context->media_info.u.audio.channels = vod_get_number_of_set_bits(channel_layout & NGX_MAX_UINT32_VALUE);
+		context->media_info.u.audio.channels = vod_get_number_of_set_bits64(channel_layout);
 		context->media_info.u.audio.channel_layout = channel_layout;
 		return VOD_OK;
 
@@ -2215,8 +2252,7 @@ mp4_parser_parse_audio_atoms(void* ctx, atom_info_t* atom_info)
 
 		channel_layout = mp4_parser_get_ac3_channel_layout(acmod, lfeon, chan_loc);
 
-		context->media_info.u.audio.channels = vod_get_number_of_set_bits(channel_layout & NGX_MAX_UINT32_VALUE) +
-			vod_get_number_of_set_bits(channel_layout >> 32);
+		context->media_info.u.audio.channels = vod_get_number_of_set_bits64(channel_layout);
 		context->media_info.u.audio.channel_layout = channel_layout;
 
 		// set the extra data to the contents of this atom, since it's used
@@ -2678,6 +2714,16 @@ mp4_parser_process_moov_atom_callback(void* ctx, atom_info_t* atom_info)
 		return rc;
 	}
 
+	// udta stream name
+	if ((context->parse_params.parse_type & PARSE_FLAG_UDTA_NAME) != 0)
+	{
+		rc = mp4_parser_parse_udta_name_atom(&trak_atom_infos.udta_name, &metadata_parse_context);
+		if (rc != VOD_OK)
+		{
+			return rc;
+		}
+	}
+
 	// get the codec type and extra data
 	rc = mp4_parser_parse_stsd_atom(&trak_atom_infos.stsd, &metadata_parse_context);
 	if (rc != VOD_OK)
@@ -2817,7 +2863,7 @@ mp4_parser_process_moov_atom_callback(void* ctx, atom_info_t* atom_info)
 
 	// check whether we should include this track
 	track_index = context->track_indexes[metadata_parse_context.media_info.media_type]++;
-	if ((context->parse_params.required_tracks_mask[metadata_parse_context.media_info.media_type] & (1 << track_index)) == 0)
+	if (!vod_is_bit_set(context->parse_params.required_tracks_mask[metadata_parse_context.media_info.media_type], track_index))
 	{
 		return VOD_OK;
 	}
@@ -2880,10 +2926,10 @@ mp4_parser_process_moov_atom_callback(void* ctx, atom_info_t* atom_info)
 	}
 
 	// add to the result array
-	if (result->base.tracks.nelts >= MAX_TRACK_COUNT)
+	if (result->base.tracks.nelts > MAX_TRACK_COUNT)
 	{
 		vod_log_error(VOD_LOG_ERR, context->request_context->log, 0,
-			"mp4_parser_process_moov_atom_callback: track count exceeded the limit");
+			"mp4_parser_process_moov_atom_callback: track count exceeded the limit of %i", (ngx_int_t)MAX_TRACK_COUNT);
 		return VOD_BAD_REQUEST;
 	}
 
